@@ -15,7 +15,7 @@ use URI::Escape qw{uri_escape_utf8};
 # of ExtUtils::MakeMaker->WriteMakefile() will accurately detect $VERSION.
 #
 my
-$VERSION = '1.000007';
+$VERSION = '1.000008';
 
 #
 # See https://tech.yandex.ru/translate/doc/dg/concepts/api-overview-docpage/
@@ -49,7 +49,7 @@ sub new
     my $class = shift;
     my $self = {
         _key_        => shift,
-        _text_       => sub { my $t = shift; return (defined $t) ? uri_escape_utf8($t) : $t },
+        _text_       => shift,
         _from_lang_  => shift,
         _to_lang_    => shift,
         _ui_         => shift || $default_ui,
@@ -57,11 +57,13 @@ sub new
         _format_     => shift,
         _options_    => shift,
         _base_       => 'https://translate.yandex.net/api/v1.5/tr.json',
-        _post_       => undef
+        _post_       => undef,
+	_http_       => HTTP::Tiny->new
     };
 
-    bless $self, $class;
-    return $self;
+    $self->{_text_} = uri_escape_utf8($self->{_text_}) if (defined $self->{_text_});
+
+    return bless $self, $class;
 }
 
 sub set_key
@@ -88,9 +90,11 @@ sub set_default_ui
 sub get_langs_list
 {
     my $self = shift;
+    die "You must set API key\n" if (not defined $self->{ _key_ });
+    
     my $query = '/getLangs?';
     $self->{_post_} = 'key='.$self->{_key_}.'&ui='.$self->{_ui_};
-    my $response = HTTP::Tiny->new->get($self->{_base_} . $query  . $self->{_post_});
+    my $response = $self->{_http_}->get($self->{_base_} . $query  . $self->{_post_});
 
     die "Invalid API key\n" if ($response->{status} eq '401');
     die "Blocked API key\n" if ($response->{status} eq '402');
@@ -123,10 +127,13 @@ sub set_hint
 sub detect_lang
 {
     my $self = shift;
+    die "You must set API key\n" if (not defined $self->{ _key_ });
+    die "You must set Text\n" if (not defined $self->{ _text_ });
+
     my $query = '/detect?';
     $self->{_post_} = 'key='.$self->{_key_}.'&text='.$self->{_text_};
     $self->{_post_} .= '&hint='.join(',', @{ $self->{_hint_} }) if (defined $self->{_hint_});
-    my $response = HTTP::Tiny->new->get($self->{_base_} . $query  . $self->{_post_});
+    my $response = $self->{_http_}->get($self->{_base_} . $query  . $self->{_post_});
 
     die "Invalid API key\n" if ($response->{status} eq '401');
     die "Blocked API key\n" if ($response->{status} eq '402');
@@ -166,12 +173,17 @@ sub set_options
 sub translate
 {
     my $self = shift;
+    die "You must set API key\n" if (not defined $self->{ _key_ });
+    die "You must set Text\n" if (not defined $self->{ _text_ });
+    die "You must set source lang\n" if (not defined $self->{ _from_lang_ });
+    die "You must set destination lang\n" if (not defined $self->{ _to_lang_ });
+
     my $query = '/translate?';
     my $lang = (defined $self->{_from_lang_}) ? $self->{_from_lang_}.'-'.$self->{_to_lang_} : $self->{_to_lang_};
     $self->{_post_} = 'key='.$self->{_key_}.'&text='.$self->{_text_}.'&lang='.$lang;
     $self->{_post_} .= '&format='.$self->{_format_} if (defined $self->{_format_});
     $self->{_post_} .= '&options='.$self->{_options_} if (defined $self->{_options_});
-    my $response = HTTP::Tiny->new->get($self->{_base_} . $query  . $self->{_post_});
+    my $response = $self->{_http_}->get($self->{_base_} . $query  . $self->{_post_});
 
     die "Invalid API key\n" if ($response->{status} eq '401');
     die "Blocked API key\n" if ($response->{status} eq '402');
@@ -245,10 +257,11 @@ Yandex::Translate - a simple API for Yandex.Translate
 
 =head1 VERSION
 
-version 1.000007
+version 1.000008
 
 =head1 SYNOPSIS
 
+    use utf8; #It is require
     use Yandex::Translate;
 
     my $tr = Yandex::Translate->new;
